@@ -19,10 +19,15 @@ import subprocess
 from urllib.parse import urlparse, urlunparse
 
 DOT_GIT = ".git"
+INTERACTIVE = False
 
 
 def run(*args):
-    return subprocess.run([str(arg) for arg in args]).check_returncode()
+    stdin = subprocess.PIPE
+    return subprocess.run(
+        [str(arg) for arg in args],
+        stdin=stdin,
+    ).check_returncode()
 
 
 def remove_ext(string, ext):
